==> search-ui-engines-connector-1.19.0.tgz: package/lib/esm/handlers/search/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit from "@searchkit/sdk";
import { EngineTransporter } from "../transporter";
import buildConfiguration, { buildBaseFilters } from "./Configuration";
import buildRequest from "./Request";
import buildResponse from "./Response";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig, host, engineName, apiKey } = configuration;
        const searchkitConfig = buildConfiguration({
            state,
            queryConfig,
            host,
            engineName,
            apiKey
        });
        const transporter = new EngineTransporter(host, engineName, configuration.apiKey, configuration.engineRouteFn);
        const request = Searchkit(searchkitConfig, transporter);
        const searchkitVariables = buildRequest(state, queryConfig);
        const baseFilters = buildBaseFilters(queryConfig.filters);
        const results = yield request
            .query(searchkitVariables.query)
            .setFilters(searchkitVariables.filters)
            .setSortBy(searchkitVariables.sort)
            .execute({
            facets: queryConfig.facets && Object.keys(queryConfig.facets).length > 0,
            hits: {
                from: searchkitVariables.from,
                size: searchkitVariables.size,
                includeRawHit: true
            }
        }, baseFilters);
        return buildResponse(results);
    });
}

==> search-ui-engines-connector-1.22.1.tgz: package/lib/esm/handlers/search/index.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Searchkit from "@searchkit/sdk";
import buildConfiguration, { buildBaseFilters } from "./Configuration";
import buildRequest from "./Request";
import buildResponse from "./Response";
export default function handleRequest(configuration) {
    return __awaiter(this, void 0, void 0, function* () {
        const { state, queryConfig } = configuration;
        const searchkitConfig = buildConfiguration({
            state,
            queryConfig
        });
        const request = Searchkit(searchkitConfig, configuration.transporter);
        const searchkitVariables = buildRequest(state, queryConfig);
        const baseFilters = buildBaseFilters(queryConfig.filters);
        const results = yield request
            .query(searchkitVariables.query)
            .setFilters(searchkitVariables.filters)
            .setSortBy(searchkitVariables.sort)
            .execute({
            facets: queryConfig.facets && Object.keys(queryConfig.facets).length > 0,
            hits: {
                from: searchkitVariables.from,
                size: searchkitVariables.size,
                includeRawHit: true
            }
        }, baseFilters);
        return buildResponse(results);
    });
}
